export declare const CONTAINER_ID_LENGTH = 64;
export declare const DEFAULT_CGROUP_V1_PATH = "/proc/self/cgroup";
export declare const DEFAULT_CGROUP_V2_PATH = "/proc/self/mountinfo";
export declare const UTF8_UNICODE = "utf8";
export declare const HOSTNAME = "hostname";
export declare const MARKING_PREFIX: string[];
export declare const CRIO = "crio-";
export declare const CRI_CONTAINERD = "cri-containerd-";
export declare const DOCKER = "docker-";
export declare const HEX_STRING_REGEX: RegExp;
export declare function truncatePrefix(lastSection: string, prefix: string): string;
export declare function extractContainerIdFromLine(line: string): string | undefined;
//# sourceMappingURL=utils.d.ts.map